==> dyte_client-0.0.5.tar.gz: android/src/main/java/com/dyteflutter/DyteMeetingPlugin.java <==
package com.dyteflutter;

import android.app.Activity;

import androidx.annotation.NonNull;

import com.dyteMobileSdk.DyteInstanceManager;
import com.dyteclientmobile.DyteMeeting;
import com.dyteclientmobile.DyteParticipant;
import com.dyteclientmobile.DyteSelfParticipant;

import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.HashMap;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.RequestPermissionsResultListener;

public class DyteMeetingPlugin implements FlutterPlugin, MethodCallHandler, RequestPermissionsResultListener, ActivityAware {
    private MethodChannel channel;
    private Activity activity;
    private DyteMeetingViewFactory factory;
    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding binding) {
        channel = new MethodChannel(binding.getBinaryMessenger(), "dyte_client");
        channel.setMethodCallHandler(this);
        this.factory = new DyteMeetingViewFactory(binding.getBinaryMessenger(),null);
        binding
                .getPlatformViewRegistry()
                .registerViewFactory("dyte-meeting-view",factory);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("selfEnableAudio")) {
            DyteMeeting.self.enableAudio();
            result.success(null);
        }else if (call.method.equals("selfDisableAudio")) {
            DyteMeeting.self.disableAudio();
            result.success(null);
        } else if (call.method.equals("selfEnableVideo")) {
            DyteMeeting.self.enableVideo();
            result.success(null);
        } else if (call.method.equals("selfDisableVideo")) {
            DyteMeeting.self.disableVideo();
            result.success(null);
        } else if (call.method.equals("selfEnableScreenSharing")) {
            DyteMeeting.self.enableScreenshare();
            result.success(null);
        } else if (call.method.equals("selfDisableScreenSharing")) {
            DyteMeeting.self.disableScreenshare();
            result.success(null);
        } else if (call.method.equals("selfPin")) {
            DyteMeeting.self.pin();
            result.success(null);
        } else if (call.method.equals("selfUnpin")) {
            DyteMeeting.self.unpin();
            result.success(null);
        } else if (call.method.equals("getSelf")) {
            DyteSelfParticipant self = DyteMeeting.self;
            HashMap<String, Object> selfResp = new HashMap<>();
            selfResp.put("id", self.id);
            selfResp.put("name", self.picture);
            selfResp.put("clientSpecificId", "");
            selfResp.put("picture", self.picture);
            selfResp.put("audioEnabled", self.audioEnabled);
            selfResp.put("videoEnabled", self.videoEnabled);
            selfResp.put("isPinned", self.isPinned);
            selfResp.put("isScreensharing", self.isScreensharing);
            result.success(selfResp);
        } else if (call.method.equals("getMeetingParticipants")) {
            ArrayList<DyteParticipant> p = DyteMeeting.participants;
            ArrayList<HashMap<String, Object>> participantsResp = new ArrayList<>();
            for(int i = 0; i< p.size(); i++) {
                DyteParticipant participant = p.get(i);
                HashMap<String, Object> resp = new HashMap<>();
                resp.put("id", participant.id);
                resp.put("name", participant.picture);
                resp.put("clientSpecificId", "");
                resp.put("picture", participant.picture);
                resp.put("audioEnabled", participant.audioEnabled);
                resp.put("videoEnabled", participant.videoEnabled);
                resp.put("isPinned", participant.isPinned);
                resp.put("isScreensharing", participant.isScreensharing);
                participantsResp.add(resp);
            }
            result.success(participantsResp);
        } else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public boolean onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        DyteInstanceManager.permissionsHandler.onRequestPermissionsResult(requestCode, permissions, grantResults);
        return false;
    }

    @Override
    public void onAttachedToActivity(@NonNull @NotNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
        binding.addRequestPermissionsResultListener(this);
        factory.setActivity(this.activity);

    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull @NotNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
        factory.setActivity(this.activity);
        binding.addRequestPermissionsResultListener(this);
    }

    @Override
    public void onDetachedFromActivity() {

    }
}

==> dyte_client-0.0.7.tar.gz: android/src/main/java/com/dyteflutter/DyteMeetingPlugin.java <==
package com.dyteflutter;

import android.app.Activity;
import android.content.Intent;
import android.content.res.Resources;

import androidx.annotation.NonNull;

import com.dyteMobileSdk.DyteInstanceManager;
import com.dyteclientmobile.DyteMeeting;
import com.dyteclientmobile.DyteParticipant;
import com.dyteclientmobile.DyteSelfParticipant;

import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.PluginRegistry.ActivityResultListener;
import io.flutter.plugin.common.PluginRegistry.RequestPermissionsResultListener;

public class DyteMeetingPlugin implements FlutterPlugin, MethodCallHandler, RequestPermissionsResultListener, ActivityAware, ActivityResultListener {
    private MethodChannel channel;
    private Activity activity;
    private DyteMeetingViewFactory factory;
    private int oldtheme = -1;
    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding binding) {
        channel = new MethodChannel(binding.getBinaryMessenger(), "dyte_client");
        channel.setMethodCallHandler(this);
        this.factory = new DyteMeetingViewFactory(binding.getBinaryMessenger(),null);
        binding
                .getPlatformViewRegistry()
                .registerViewFactory("dyte-meeting-view",factory);

        DyteMeeting.addEventListener(new DyteMeeting.MeetingEventListener() {
            @Override
            public void meetingJoined() {
                channel.invokeMethod("eventMeetingJoined", null);
            }

            @Override
            public void meetingEnded() {
                channel.invokeMethod("eventMeetingEnded", null);
            }

            @Override
            public void connect() {
                channel.invokeMethod("eventMeetingConnected", null);
            }

            @Override
            public void activeSpeaker(DyteParticipant participant) {
                Map<String, String> args = new HashMap();
                args.put("id", participant.id);
                channel.invokeMethod("eventActiveSpeaker", args);
            }

            @Override
            public void participantJoin(DyteParticipant participant) {
                Map<String, String> args = new HashMap();
                args.put("id", participant.id);
                channel.invokeMethod("eventParticipantJoin", args);
            }

            @Override
            public void participantLeave(DyteParticipant participant) {
                Map<String, String> args = new HashMap();
                args.put("id", participant.id);
                channel.invokeMethod("eventParticipantLeave", args);
            }

            @Override
            public void disconnect() {
                channel.invokeMethod("eventMeetingDisconnected", null);
            }

            @Override
            public void message(HashMap<String, Object> data) {

            }

            @Override
            public void roomMessage(HashMap<String, Object> data) {

            }

            @Override
            public void participantUpdated(DyteParticipant participant) {

            }
        });
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("selfEnableAudio")) {
            DyteMeeting.self.enableAudio();
            result.success(null);
        }else if (call.method.equals("selfDisableAudio")) {
            DyteMeeting.self.disableAudio();
            result.success(null);
        } else if (call.method.equals("selfEnableVideo")) {
            DyteMeeting.self.enableVideo();
            result.success(null);
        } else if (call.method.equals("selfDisableVideo")) {
            DyteMeeting.self.disableVideo();
            result.success(null);
        } else if (call.method.equals("selfEnableScreenSharing")) {
            DyteMeeting.self.enableScreenshare();
            result.success(null);
        } else if (call.method.equals("selfDisableScreenSharing")) {
            DyteMeeting.self.disableScreenshare();
            result.success(null);
        } else if (call.method.equals("selfPin")) {
            DyteMeeting.self.pin();
            result.success(null);
        } else if (call.method.equals("selfUnpin")) {
            DyteMeeting.self.unpin();
            result.success(null);
        } else if (call.method.equals("getSelf")) {
            DyteSelfParticipant self = DyteMeeting.self;
            HashMap<String, Object> selfResp = new HashMap<>();
            selfResp.put("id", self.id);
            selfResp.put("name", self.picture);
            selfResp.put("clientSpecificId", "");
            selfResp.put("picture", self.picture);
            selfResp.put("audioEnabled", self.audioEnabled);
            selfResp.put("videoEnabled", self.videoEnabled);
            selfResp.put("isPinned", self.isPinned);
            selfResp.put("isScreensharing", self.isScreensharing);
            result.success(selfResp);
        } else if (call.method.equals("getMeetingParticipants")) {
            ArrayList<DyteParticipant> p = DyteMeeting.participants;
            ArrayList<HashMap<String, Object>> participantsResp = new ArrayList<>();
            for(int i = 0; i< p.size(); i++) {
                DyteParticipant participant = p.get(i);
                HashMap<String, Object> resp = new HashMap<>();
                resp.put("id", participant.id);
                resp.put("name", participant.picture);
                resp.put("clientSpecificId", "");
                resp.put("picture", participant.picture);
                resp.put("audioEnabled", participant.audioEnabled);
                resp.put("videoEnabled", participant.videoEnabled);
                resp.put("isPinned", participant.isPinned);
                resp.put("isScreensharing", participant.isScreensharing);
                participantsResp.add(resp);
            }
            result.success(participantsResp);
        } else if (call.method.equals("updateUIConfig")) {
            String json = call.argument("config");
            DyteMeeting.updateUIConfig(json);
        }
        else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public boolean onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        DyteInstanceManager.permissionsHandler.onRequestPermissionsResult(requestCode, permissions, grantResults);
        return false;
    }

    @Override
    public void onAttachedToActivity(@NonNull @NotNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
        try {
            this.oldtheme = activity.getPackageManager().getActivityInfo(activity.getComponentName(), 0).getThemeResource();
        } catch (Exception e){

        }
        this.activity.setTheme(R.style.Theme_AppCompat_NoActionBar);
        binding.addRequestPermissionsResultListener(this);
        factory.setActivity(this.activity);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        if (DyteInstanceManager.reactInstanceManager != null) {
            DyteInstanceManager.reactInstanceManager.onHostPause(this.activity);
        }
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull @NotNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
        factory.setActivity(this.activity);
        binding.addRequestPermissionsResultListener(this);
        if (DyteInstanceManager.reactInstanceManager != null) {
            DyteInstanceManager.reactInstanceManager.onHostResume(this.activity);
        }
    }

    @Override
    public void onDetachedFromActivity() {
        if(this.oldtheme != -1){
            this.activity.setTheme(this.oldtheme);
        }
        if (DyteInstanceManager.reactInstanceManager != null) {
            DyteInstanceManager.reactInstanceManager.onHostDestroy(this.activity);
        }
        if (DyteInstanceManager.reactInstanceManager != null) {
            DyteInstanceManager.reactRootView.unmountReactApplication();
        }
    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
        if (DyteInstanceManager.reactInstanceManager != null) {
            DyteInstanceManager.reactInstanceManager.onActivityResult(this.activity, requestCode, resultCode, data);
        }
        return false;
    }
}
